@@ -1318,7 +1318,11 @@ secu_PrintUniversal(FILE *out, SECItem *i, char *m, int level)
 	    SECU_PrintUTCTime(out, i, m, level);
 	    break;
 	  case SEC_ASN1_NULL:
-	    SECU_Indent(out, level); fprintf(out, "%s: NULL\n", m);
+	    SECU_Indent(out, level); 
+	    if (m && m[0]) 
+	      fprintf(out, "%s: NULL\n", m);
+	    else
+	      fprintf(out, "NULL\n");
 	    break;
           case SEC_ASN1_SET:
           case SEC_ASN1_SEQUENCE:
@@ -1806,14 +1810,6 @@ secu_PrintAuthKeyIDExtension(FILE *out, SECItem *value, char *msg, int level)
 	int snPresent = (kid->authCertSerialNumber.data &&
 	                 kid->authCertSerialNumber.len);
 
-        if ((keyIDPresent && !issuerPresent && !snPresent) ||
-	    (!keyIDPresent && issuerPresent && snPresent)) {
-	    /* all is well */
-	} else {
-	    SECU_Indent(out, level);
-	    fprintf(out, 
-	    "Error: KeyID OR (Issuer AND Serial) must be present, not both.\n");
-	}
 	if (keyIDPresent)
 	    SECU_PrintAsHex(out, &kid->keyID, "Key ID", level);
 	if (issuerPresent)
@@ -3008,25 +3004,6 @@ loser:
 
 }
 
-
-SECItem *
-SECU_GetPBEPassword(void *arg)
-{
-    char *p = NULL;
-    SECItem *pwitem = NULL;
-
-    p = SECU_GetPasswordString(arg,"Password: ");
-
-    /* NOTE: This function is obviously unfinished. */
-
-    if ( pwitem == NULL ) {
-	fprintf(stderr, "Error hashing password\n");
-	return NULL;
-    }
-    
-    return pwitem;
-}
-
 SECStatus
 SECU_ParseCommandLine(int argc, char **argv, char *progName, secuCommand *cmd)
 {
@@ -3078,7 +3055,9 @@ SECU_ParseCommandLine(int argc, char **argv, char *progName, secuCommand *cmd)
 		cmd->options[i].activated = PR_TRUE;
 		if (optstate->value) {
 		    cmd->options[i].arg = (char *)optstate->value;
-		}
+		} else if (cmd->options[i].needsArg) {
+                    return SECFailure;
+                }
 		found = PR_TRUE;
 		break;
 	    }
@@ -3608,10 +3587,8 @@ CERTCertificate *
 SECU_FindCrlIssuer(CERTCertDBHandle *dbhandle, SECItem* subject,
                    CERTAuthKeyID* authorityKeyID, PRTime validTime)
 {
-    CERTCertListNode *node;
-    CERTCertificate * issuerCert = NULL, *cert = NULL;
+    CERTCertificate *issuerCert = NULL;
     CERTCertList *certList = NULL;
-    SECStatus rv = SECFailure;
 
     if (!subject) {
         PORT_SetError(SEC_ERROR_INVALID_ARGS);
@@ -3621,32 +3598,24 @@ SECU_FindCrlIssuer(CERTCertDBHandle *dbhandle, SECItem* subject,
     certList =
         CERT_CreateSubjectCertList(NULL, dbhandle, subject,
                                    validTime, PR_TRUE);
-    if (!certList) {
-        goto loser;
-    }
-
-    node = CERT_LIST_HEAD(certList);
-    
-    /* XXX and authoritykeyid in the future */
-    while ( ! CERT_LIST_END(node, certList) ) {
-	cert = node->cert;
-        if (CERT_CheckCertUsage(cert, KU_CRL_SIGN) != SECSuccess ||
-            !cert->trust) {
-            continue;
-        }
-        /* select the first (newest) user cert */
-        if (CERT_IsUserCert(cert)) {
-            rv = SECSuccess;
-            goto success;
-        }
-    }
-
-  success:
-    if (rv == SECSuccess) {
-        issuerCert = CERT_DupCertificate(cert);
-    }
-  loser:
     if (certList) {
+        CERTCertListNode *node = CERT_LIST_HEAD(certList);
+    
+        /* XXX and authoritykeyid in the future */
+        while ( ! CERT_LIST_END(node, certList) ) {
+            CERTCertificate *cert = node->cert;
+            /* check cert CERTCertTrust data is allocated, check cert
+               usage extension, check that cert has pkey in db. Select
+               the first (newest) user cert */
+            if (cert->trust &&
+                CERT_CheckCertUsage(cert, KU_CRL_SIGN) == SECSuccess &&
+                CERT_IsUserCert(cert)) {
+                
+                issuerCert = CERT_DupCertificate(cert);
+                break;
+            }
+            node = CERT_LIST_NEXT(node);   
+        }
         CERT_DestroyCertList(certList);
     }
     return(issuerCert);
